@@ -1,6 +1,5 @@
 use anyhow::{ensure, Context};
 use bellperson::{
-    bls::{Bls12, Fr},
     groth16::{
         self,
         aggregate::{
@@ -11,6 +10,7 @@ use bellperson::{
     },
     Circuit,
 };
+use blstrs::{Bls12, Scalar as Fr};
 use log::info;
 use rand::{rngs::OsRng, RngCore};
 use rayon::prelude::{
@@ -53,7 +53,7 @@ pub trait CircuitComponent {
 /// See documentation at proof::ProofScheme for details.
 /// Implementations should generally only need to supply circuit and generate_public_inputs.
 /// The remaining trait methods are used internally and implement the necessary plumbing.
-pub trait CompoundProof<'a, S: ProofScheme<'a>, C: Circuit<Bls12> + CircuitComponent + Send>
+pub trait CompoundProof<'a, S: ProofScheme<'a>, C: Circuit<Fr> + CircuitComponent + Send>
 where
     S::Proof: Sync + Send,
     S::PublicParams: ParameterSetMetadata + Sync + Send,
@@ -278,14 +278,18 @@ where
     }
 
     /// Given a prover_srs key, a list of groth16 proofs, and an ordered list of seeds
-    /// (used to derive the PoRep challenges) hashed using FIXME, aggregate them all into
+    /// (used to derive the PoRep challenges) hashed pair-wise with the comm_rs using sha256, aggregate them all into
     /// an AggregateProof type.
     fn aggregate_proofs(
         prover_srs: &ProverSRS<Bls12>,
-        hashed_seeds: &[u8],
+        hashed_seeds_and_comm_rs: &[u8],
         proofs: &[groth16::Proof<Bls12>],
     ) -> Result<AggregateProof<Bls12>> {
-        Ok(aggregate_proofs::<Bls12>(prover_srs, hashed_seeds, proofs)?)
+        Ok(aggregate_proofs::<Bls12>(
+            prover_srs,
+            hashed_seeds_and_comm_rs,
+            proofs,
+        )?)
     }
 
     /// Verifies the aggregate proof, with respect to the flattened input list.
@@ -298,7 +302,7 @@ where
     fn verify_aggregate_proofs(
         ip_verifier_srs: &VerifierSRS<Bls12>,
         pvk: &PreparedVerifyingKey<Bls12>,
-        hashed_seeds: &[u8],
+        hashed_seeds_and_comm_rs: &[u8],
         public_inputs: &[Vec<Fr>],
         aggregate_proof: &groth16::aggregate::AggregateProof<Bls12>,
     ) -> Result<bool> {
@@ -310,7 +314,7 @@ where
             &mut rng,
             public_inputs,
             aggregate_proof,
-            hashed_seeds,
+            hashed_seeds_and_comm_rs,
         )?)
     }
 
