@@ -1,9 +1,8 @@
 use std::collections::BTreeSet;
 use std::fmt::{self, Display, Formatter};
 
-use bellperson::bls::{Fr, FrRepr};
+use blstrs::Scalar as Fr;
 use byteorder::{ByteOrder, LittleEndian};
-use ff::PrimeField;
 use serde::{Deserialize, Serialize};
 
 /// An ordered set of `SectorId`s.
@@ -29,7 +28,7 @@ impl From<SectorId> for u64 {
 
 impl From<SectorId> for Fr {
     fn from(n: SectorId) -> Self {
-        Fr::from_repr(FrRepr::from(n.0)).expect("from repr failure")
+        Fr::from(n.0)
     }
 }
 
